@@ -1,9 +1,10 @@
 from flask import Flask
 from flask.ctx import has_request_context
 from frasco.config import Config
-from frasco.utils import JSONEncoder, AttrDict
+from frasco.utils import AttrDict
+from frasco.json_decoder import JSONEncoder
 from frasco.templating import configure_environment
-from werkzeug.contrib.fixers import ProxyFix
+from werkzeug.middleware.proxy_fix import ProxyFix
 import os
 import sys
 
