@@ -1,15 +1,10 @@
 from werkzeug.utils import import_string as wz_import_string, cached_property
-from werkzeug.local import LocalProxy, LocalStack
-from flask import (url_for, Markup, json, request, _request_ctx_stack,\
-                   has_request_context, abort, current_app)
-import imp
+from flask import abort
+from slugify import slugify
 import functools
 import re
-from slugify import slugify
 import yaml
-import speaklater
 import os
-from contextlib import contextmanager
 import subprocess
 import click
 import inspect
@@ -72,6 +67,36 @@ def find_classes_in_module(module, clstypes):
     return classes
 
 
+class ImportClassError(ImportError):
+    pass
+
+
+def find_class_in_module(cls, clstypes):
+    if not isinstance(clstypes, (tuple, list)):
+        clstypes = (clstypes,)
+
+    if inspect.ismodule(cls):
+        classes = find_classes_in_module(cls, clstypes)
+        if not classes:
+            raise ImportClassError('No extension class found in module')
+        if len(classes) > 1:
+            raise ImportClassError('Too many extension classes in module')
+        return classes[0]
+
+    if not isinstance(cls, clstypes):
+        raise ImportClassError("Wrong class type")
+    return cls
+
+
+def import_class(impstr, clstypes, fallback_package=None):
+    try:
+        return find_class_in_module(import_string(impstr), clstypes)
+    except ImportError as e:
+        if not fallback_package or ('No module named' not in str(e) and str(e) != 'No extension class found in module'):
+            raise
+        return find_class_in_module(import_string(fallback_package + "." + impstr), clstypes)
+
+
 def remove_yaml_frontmatter(source, return_frontmatter=False):
     """If there's one, remove the YAML front-matter from the source
     """
@@ -94,7 +119,7 @@ def remove_yaml_frontmatter(source, return_frontmatter=False):
 def parse_yaml_frontmatter(source):
     source, frontmatter = remove_yaml_frontmatter(source, True)
     if frontmatter:
-        return (yaml.load(frontmatter), source)
+        return (yaml.safe_load(frontmatter), source)
     return (None, source)
 
 
@@ -105,24 +130,6 @@ def populate_obj(obj, attrs):
         setattr(obj, k, v)
 
 
-def url_for_static(filename, **kwargs):
-    """Shortcut function for url_for('static', filename=filename)
-    """
-    return url_for('static', filename=filename, **kwargs)
-
-
-def url_for_same(**overrides):
-    return url_for(request.endpoint, **dict(dict(request.args,
-        **request.view_args), **overrides))
-
-
-def wrap_in_markup(f):
-    @functools.wraps(f)
-    def wrapper(*args, **kwargs):
-        return Markup(f(*args, **kwargs))
-    return wrapper
-
-
 def make_kwarg_validator(name, validator_func):
     if not isinstance(name, tuple):
         name = (name,)
@@ -145,13 +152,6 @@ def kwarg_validator(name):
     return decorator
 
 
-def inject_app_config(app, config, prefix=None):
-    for k, v in config.iteritems():
-        if prefix:
-            k = "%s%s" % (prefix, k)
-        app.config[k.upper()] = v
-
-
 def extract_unmatched_items(items, allowed_keys, prefix=None, uppercase=False):
     unmatched = {}
     for k, v in items.iteritems():
@@ -207,27 +207,15 @@ class AttrDict(dict):
         return dict(self)
 
 
-class JSONEncoder(json.JSONEncoder):
-    """A JSONEncoder which always activates the for_json feature
-    """
-    def __init__(self, *args, **kwargs):
-        kwargs["for_json"] = True
-        super(JSONEncoder, self).__init__(*args, **kwargs)
-
-    def default(self, o):
-        if isinstance(o, speaklater._LazyString):
-            return o.value
-        if isinstance(o, set):
-            return list(o)
-        return json.JSONEncoder.default(self, o)
-
-
 class ShellError(Exception):
     def __init__(self, returncode, stderr):
         super(ShellError, self).__init__(stderr)
         self.returncode = returncode
         self.stderr = stderr
 
+    def __unicode__(self):
+        return unicode(self.stderr)
+
 
 def shell_exec(args, echo=True, fg="green", **kwargs):
     kwargs["stdout"] = subprocess.PIPE
@@ -241,13 +229,6 @@ def shell_exec(args, echo=True, fg="green", **kwargs):
     return out
 
 
-def get_remote_addr():
-    if current_app.debug and "__remoteaddr" in request.values:
-        return request.values["__remoteaddr"]
-    return request.remote_addr
-
-
-
 def match_domains(domain, allowed_domains):
     for allowed_domain in allowed_domains:
         if allowed_domain.startswith('^'):
@@ -274,3 +255,11 @@ def remove_all_handlers_from_logger(logger):
 class ExcludeWerkzeugLogFilter(logging.Filter):
     def filter(self, record):
         return record.name != 'werkzeug'
+
+
+def join_url_rule(rule1, rule2):
+    if not rule1:
+        return rule2
+    if not rule2:
+        return rule1
+    return (rule1.rstrip('/') + '/' + rule2.lstrip('/')).rstrip('/')
